# autolaunch

`autolaunch` est une bibliothèque Python permettant d'enregistrer automatiquement des applications Python pour qu'elles puissent être lancées depuis n'importe où en utilisant simplement leur nom.

## Installation
```bash
pip install autolaunch
